# Articles
## Wave Optics
Fourier Modal Method:
- <https://github.com/facebookresearch/fmmax>



## FDTD
<https://github.com/flaport/fdtd>



## Maxwell-Bloch
<https://maxwellbloch.readthedocs.io/en/stable/>



## Diffraction
<https://rafael-fuente.github.io/simulating-diffraction-patterns-with-the-angular-spectrum-method-and-python.html>



## Chiroptical Properties
**Chiroptical Properties Overview**
- <https://www.nature.com/articles/s41377-020-00367-8>
- *Also PDF*.

Circular Dichroism Spectroscopy
- <https://chem.libretexts.org/Bookshelves/Analytical_Chemistry/Physical_Methods_in_Chemistry_and_Nano_Science_(Barron)/07%3A_Molecular_and_Solid_State_Structure/7.07%3A_Circular_Dichroism_Spectroscopy_and_its_Application_for_Determination_of_Secondary_Structure_of_Optically_Active_Species>

Absolute Configuration
- Spatial arrangement of atoms within a chiral molecular entity
- <https://en.wikipedia.org/wiki/Absolute_configuration>

Optical Rotary Dispersion
- Variation in the optical rotation of a substance with a change in the wavelength of light.
- <https://en.wikipedia.org/wiki/Optical_rotatory_dispersion>



## Molecular Dynamics related to Varying Chiral Responses to EM Fields
Perspectives on external electric fields in molecular simulation: progress, prospects and challenges
- General overview of molecular simulation type stuff.
- Brings me to *English et al.* article.
- <https://pubs.rsc.org/en/content/articlehtml/2015/cp/c5cp00629e#cit62>

Coupling of translational and rotational motion in chiral liquids in electromagnetic and circularly polarised electric fields 
- <https://pubmed.ncbi.nlm.nih.gov/22401453/>



## General PDE Learning
Intro to Maxwell PDE Solutions
- Slides: <https://cmpp.readthedocs.io/en/latest/_static/lec3-2021.pdf>

## FEM Tool Aggregators
Resume of This Guy:
- <https://mbarzegary.github.io/whatiuse/>

Blog Post of This Guy:
- <https://www.matecdev.com/posts/differences-fdtd-fem-mom.html>

Differentiable Solvers (fluid-focused):
- <https://danmackinlay.name/notebook/pde_solvers_diff.html#phiflow>

Survey of Julia-Based PDE Solvers:
- <https://github.com/JuliaPDE/SurveyofPDEPackages>

## Geometry Tools
pygmsh
- Nice abstraction on top of `gmsh`.
- PyPi: <https://pypi.org/project/pygmsh/>

## FEM Learning
Wikipedia: <https://en.wikipedia.org/wiki/Finite_element_method>

Finite Element Encyclopedia
- Home: <https://defelement.com/>
- Nedelec: <https://defelement.com/elements/nedelec1.html>

Introduction to FEM for Maxwell
- <https://www.math.uci.edu/~chenlong/226/FEMMaxwell.pdf>

## FEM Solvers
COMSOL
- **NOT Open Source**. Pedatory license.
- General-purpose PDE solver.
- Limited Python Interface: <https://mph.readthedocs.io/en/stable/installation.html>

FEniCS
- **NO GPU**
- Extremely advanced Python muliphysics solver.
- Project: <https://fenicsproject.org/>
- Sphere EM Scattering: <https://docs.fenicsproject.org/dolfinx/v0.7.2/python/demos/demo_axis.html>
- Finite Elements for Maxwell Solvers: <https://fenicsproject.org/olddocs/dolfin/2018.1.0/python/demos/maxwell-eigenvalues/demo_maxwell-eigenvalues.py.html>
- Maxwell Eigenvalue FEM Solver: <https://github.com/gamstc/fenics_maxwell/blob/master/maxwell_eigs_simple.py>
- JAX Integration for Autograd: <https://github.com/IvanYashchuk/jax-fenics>
- Tutorial: <https://jsdokken.com/dolfinx-tutorial/chapter3/em.html>
- Multiphysics Models in FEniCS: <https://www.sciencedirect.com/science/article/pii/S266709922300004X#sec0020>
- Gallery of FEM Solvers: <https://fenicsproject.org/pub/tutorial/sphinx1/._ftut1004.html>
- The FEniCS Tutorial Volume 1: <https://fenicsproject.org/pub/tutorial/sphinx1/>

FreeFEM: 
- Domain-specific C++-like language
- Documentation: <https://doc.freefem.org/introduction/index.html>
- <https://freefem.org/>

Elmer:
- Project: <https://www.elmerfem.org/blog/>
- Models: <https://www.nic.funet.fi/pub/sci/physics/elmer/doc/ElmerModelsManual.pdf>
- Python Interface: <https://pypi.org/project/pyelmer/>
- Docker: <https://hub.docker.com/r/nwrichmond/elmerice/>

jax-fem:
- Doesn't seem to do much (if any) wave stuff.
- Repo: <https://github.com/tianjuxue/jax-fem>
- Paper: <https://www.sciencedirect.com/science/article/pii/S0010465523001479#kws0010>
- Sister Project for Additive Manufacturing: <https://github.com/tianjuxue/jax-am>

deal.II:
- A crazy C++ library.
- <https://www.dealii.org/>

## Julia FEM Solvers
BEAST:
- <https://github.com/krcools/BEAST.jl>

## FEM Fluid Solvers
<https://github.com/tum-pbs/PhiFlow>

## FEM Theory
Matrix-Free FEM Solver
- Paper: <https://www.iitg.ac.in/dsharma/papers/journal/2020_EBE_SYM_FEA.pdf>

## Topological Optimization
FreeFEM-based Topology Optimization
- Paper: <https://link.springer.com/article/10.1007/s00158-023-03529-5#Sec7>
